summaryrefslogtreecommitdiff
path: root/eaaf_core/src/main/java/at/gv/egiz/eaaf/core/impl/idp/auth/services/IErrorService.java
diff options
context:
space:
mode:
Diffstat (limited to 'eaaf_core/src/main/java/at/gv/egiz/eaaf/core/impl/idp/auth/services/IErrorService.java')
-rw-r--r--eaaf_core/src/main/java/at/gv/egiz/eaaf/core/impl/idp/auth/services/IErrorService.java27
1 files changed, 22 insertions, 5 deletions
diff --git a/eaaf_core/src/main/java/at/gv/egiz/eaaf/core/impl/idp/auth/services/IErrorService.java b/eaaf_core/src/main/java/at/gv/egiz/eaaf/core/impl/idp/auth/services/IErrorService.java
index b6bc1056..45b1cfe8 100644
--- a/eaaf_core/src/main/java/at/gv/egiz/eaaf/core/impl/idp/auth/services/IErrorService.java
+++ b/eaaf_core/src/main/java/at/gv/egiz/eaaf/core/impl/idp/auth/services/IErrorService.java
@@ -1,8 +1,12 @@
package at.gv.egiz.eaaf.core.impl.idp.auth.services;
+import java.util.Map;
+
import javax.annotation.Nonnull;
+import javax.annotation.Nullable;
import javax.servlet.http.HttpServletRequest;
+import at.gv.egiz.eaaf.core.api.IRequest;
import at.gv.egiz.eaaf.core.api.gui.ModifyableGuiBuilderConfiguration;
import at.gv.egiz.eaaf.core.exceptions.EaafException;
@@ -94,14 +98,19 @@ public interface IErrorService {
/**
* Creates error handling data.
*
* @param throwable Error that should be handled
* @param supportRedirctToSp <code>true</code> if the current process-state supports redirect
* to Service-Provider, otherwise <code>false</code>
* @return Information how the error should be handled
* @throws EaafException In case of an internal error
*/
@Nonnull
- IHandleData createHandleData(@Nonnull Throwable throwable, boolean supportRedirctToSp) throws EaafException;
+ IHandleData createHandleData(@Nonnull Throwable throwable, @Nullable IRequest protocolRequest)
+ throws EaafException;
/**
* Displays the error using suitable errordata.
@@ -160,5 +169,13 @@ public interface IErrorService {
* @return log message
*/
String getPreFormatedErrorMessage();
+
+ /**
+ * Get additional elements for error GUI model.
+ *
+ * @return Map of GUI model elements.
+ */
+ Map<String, String> getAdditionalGuiModelElements();
+
}
}
@@ -94,14 +98,19 @@ public interface IErrorService {
* Creates error handling data.
*
- * @param throwable Error that should be handled
- * @param supportRedirctToSp <code>true</code> if the current process-state supports redirect
- * to Service-Provider, otherwise <code>false</code>
- * @return Information how the error should be handled
+ * <p>
+ * Redirect to Service-Provider is supported in case of an available
+ * pendingRequest.
+ * </p>
+ *
+ * @param throwable Error that should be handled
+ * @param protocolRequest Current pendingRequest if available
+ * @return Information how the error should be handled
* @throws EaafException In case of an internal error
*/